<?php

namespace Litepie\Service\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Service\Http\Requests\ServiceCategoryRequest;
use Litepie\Service\Interfaces\ServiceCategoryRepositoryInterface;
use Litepie\Service\Models\ServiceCategory;
use Litepie\Service\Forms\ServiceCategory as Form;

/**
 * APIController  class for service_category.
 */
class ServiceCategoryAPIController extends BaseController
{

    /**
     * Initialize service_category resource controller.
     *
     * @param type ServiceCategoryRepositoryInterface $service_category
     *
     * @return null
     */
    public function __construct(ServiceCategoryRepositoryInterface $service_category)
    {
        parent::__construct();
        $this->repository = $service_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Service\Repositories\Criteria\ServiceCategoryResourceCriteria::class);
    }

    /**
     * Display a list of service_category.
     *
     * @return Response
     */
    public function index(ServiceCategoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Service\Repositories\Presenter\ServiceCategoryPresenter::class)
            ->paginate();
    }

    /**
     * Display service_category.
     *
     * @param Request $request
     * @param Model   $service_category
     *
     * @return Response
     */
    public function show(ServiceCategoryRequest $request, ServiceCategory $service_category)
    {
        return $service_category->setPresenter(\Litepie\Service\Repositories\Presenter\ServiceCategoryListPresenter::class);
        ;
    }

    /**
     * Create new service_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ServiceCategoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('service::service_category.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('service/service_category/' . $service_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/service_category');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the service_category.
     *
     * @param Request $request
     * @param Model   $service_category
     *
     * @return Response
     */
    public function update(ServiceCategoryRequest $request, ServiceCategory $service_category)
    {
        try {
            $data = $request->all();

            $service_category->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('service::service_category.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('service/service_category/' . $service_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/service_category/' . $service_category->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the service_category.
     *
     * @param Model   $service_category
     *
     * @return Response
     */
    public function destroy(ServiceCategoryRequest $request, ServiceCategory $service_category)
    {
        try {
            $service_category->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('service::service_category.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('service/service_category/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('service/service_category/' . $service_category->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
