<?php

namespace Litepie\Service\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Service\Interfaces\ServiceReviewRepositoryInterface;

class ServiceReviewPublicController extends BaseController
{
    // use ServiceReviewWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\ServiceReview\Interfaces\ServiceReviewRepositoryInterface $service_review
     *
     * @return type
     */
    public function __construct(ServiceReviewRepositoryInterface $service_review)
    {
        $this->repository = $service_review;
        parent::__construct();
    }

    /**
     * Show service_review's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $service_reviews = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('service::service_review.names'))
            ->view('service::public.service_review.index')
            ->data(compact('service_reviews'))
            ->output();
    }


    /**
     * Show service_review.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $service_review = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($service_review->name . trans('service::service_review.name'))
            ->view('service::public.service_review.show')
            ->data(compact('service_review'))
            ->output();
    }

}
